@@ -1,8 +1,8 @@
 #ifndef HTTVERSION_H
 #define HTTVERSION_H
 
-#define HTTQTVERSION  "1.4.6"
-#define PROGRAM_DATE  "13 Nov 2015"
+#define HTTQTVERSION  "1.4.8"
+#define PROGRAM_DATE  "20 Jan 2017"
 
 #define USE_QT_VERSION  4
 
